==> bitcream-ndt-pim-user-reserved-area-v0.6-0258ab.zip: api/controllers/CollectionController.php <==
<?php

namespace bitcream\ndt\reservedarea\api\controllers;

use Yii;
use yii\rest\ActiveController;
use yii\filters\AccessControl;
use bitcream\ndt\reservedarea\api\models\Collection;
use bitcream\ndt\custom\common\models\CustomerUser;
use yii\data\ActiveDataFilter;
use yii\data\ActiveDataProvider;

class CollectionController extends ActiveController
{
    public $modelClass = 'bitcream\ndt\reservedarea\api\models\Collection';

    /**
     * @inheritdoc
    */

    public function behaviors(): array
    {
        return array_merge(parent::behaviors(), 
            [
                'authenticator' => [
                    'class' => \Kakadu\Yii2JwtAuth\JwtBearerAuth::class,
                    'except' => ['options'],
                ],
                'access'        => [
                    'class' => AccessControl::class,
                    'rules' => [
                        [
                            'allow' => true,
                            'roles' => ['@'],
                        ],
                    ],
                ],
            ]
        );
    }

    public function actions(){
        $actions = parent::actions();

        $actions['index']['prepareDataProvider'] = [$this, 'prepareDataProvider'];

        return $actions;
    }

    public function prepareDataProvider(){
        $filter = new ActiveDataFilter([
            'searchModel' => 'bitcream\ndt\reservedarea\api\models\CollectionSearch'
        ]);

        $filterCondition = null;
        
        // You may load filters from any source. For example,
        // if you prefer JSON in request body,
        // use Yii::$app->request->getBodyParams() below:
        if ($filter->load(\Yii::$app->request->get())) { 
            $filterCondition = $filter->build();
            if ($filterCondition === false) {
                // Serializer would get errors out of it
                return $filter;
            }
        }
        $query = Collection::find()->where(['customer_user_id' => Yii::$app->user->id]);
          
        if ($filterCondition !== null) {            
            $query->andWhere($filterCondition);
        }
        
        return new ActiveDataProvider([
            'query' => $query,
        ]);
    }

}

==> bitcream-ndt-pim-user-reserved-area-v0.7.1-4817b3.zip: api/controllers/CollectionController.php <==
<?php

namespace bitcream\ndt\reservedarea\api\controllers;

use Yii;
use yii\rest\ActiveController;
use yii\filters\AccessControl;
use bitcream\ndt\reservedarea\api\models\CollectionCustomerUser;
use bitcream\ndt\reservedarea\api\models\Collection;
use bitcream\ndt\custom\common\models\CustomerUser;
use yii\data\ActiveDataFilter;
use yii\data\ActiveDataProvider;

class CollectionController extends ActiveController
{
    public $modelClass = 'bitcream\ndt\reservedarea\api\models\Collection';

    /**
     * @inheritdoc
    */

    public function behaviors(): array
    {
        return array_merge(parent::behaviors(), 
            [
                'authenticator' => [
                    'class' => \Kakadu\Yii2JwtAuth\JwtBearerAuth::class,
                    'except' => ['options'],
                ],
                'access'        => [
                    'class' => AccessControl::class,
                    'rules' => [
                        [
                            'allow' => true,
                            'roles' => ['@'],
                        ],
                    ],
                ],
            ]
        );
    }

    public function actions(){
        $actions = parent::actions();
        $actions['index']['prepareDataProvider'] = [$this, 'prepareDataProvider'];

        return $actions;
    }

    public function beforeAction($action)
    {
        $headers = Yii::$app->request->headers;
        //$langHeader = $headers->get('Accept-Language');

        if(isset($langHeader)){
            $language = explode("-", $langHeader);
            if($action->id =='index'){
                CustomerUser::setUserLanguage($language[0]);
            }
        }
        if (!parent::beforeAction($action)) {
            return false;
        }
        return true; // or false to not run the action
    }

    public function prepareDataProvider(){
        $filter = new ActiveDataFilter([
            'searchModel' => 'bitcream\ndt\reservedarea\api\models\CollectionSearch'
        ]);

        $filterCondition = null;
        
        // You may load filters from any source. For example,
        // if you prefer JSON in request body,
        // use Yii::$app->request->getBodyParams() below:
        if ($filter->load(\Yii::$app->request->get())) { 
            $filterCondition = $filter->build();
            if ($filterCondition === false) {
                // Serializer would get errors out of it
                return $filter;
            }
        }
        $query = Collection::find()
                    ->join('JOIN','collection_customer_user','collection_customer_user.collection_id = collection.id')
                    ->where(['collection_customer_user.customer_user_id' => Yii::$app->user->id]);
          
        if ($filterCondition !== null) {            
            $query->andWhere($filterCondition);
        }
        
        return new ActiveDataProvider([
            'query' => $query,
        ]);
    }

}
